@@ -1,4 +1,5 @@
 import argparse
+import json
 from pathlib import Path
 from azureml.core import Run
 from ml_cli import run_ml_cli
@@ -56,4 +57,19 @@ output_jsons = str(data_output_dir_path / json_chunk_name)
 
 run_ml_cli(str(Path(raw_data_dir) / chunk_name), output_jsons, mlcli_template)
 
+
+dir_list = [p for p in Path(output_jsons).iterdir() if p.is_dir()]
+
+for dir_path in dir_list:
+    dir_name = dir_path.name
+    source = str(output_jsons / dir_name)
+    dummy_path = str(output_jsons / dir_name / 'dummy.json')
+
+    subdir_list = [p for p in Path(source).iterdir() if p.is_dir()]
+    subfiles_list = [p for p in Path(source).iterdir() if p.is_file()]
+    if len(subfiles_list) <= 0 < len(subdir_list):
+        with open(dummy_path, 'w') as f:
+            json.dump({}, f, indent=2)
+
+
 run.complete()
